//#define __USE_BSD
#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <dirent.h>
#include "version.h"
#include "ls.h"


int ls_main (int argc, char **argv) {
	DIR *dirtype;
	struct dirent *dinfo;
	char pwd[256];

	if (argc==1) {
		strcpy(pwd,".");
	} else {
		strcpy(pwd,argv[1]);
	}

	if ((dirtype=opendir(pwd))==NULL) return(-1);
	while (1) {
		if ((dinfo=readdir(dirtype))==NULL) break;
		printf("%s\n",dinfo->d_name);
	}
	closedir(dirtype);
	return(0);
}
